import math

import pygame

DIAL_SCALING = 0.9


class Dial(pygame.Surface):
    def __init__(self, dial_size):
        super().__init__((dial_size, dial_size), pygame.SRCALPHA)
        self.rect = self.get_rect()
        self.dial_size = dial_size
        self.center = (self.dial_size / 2, self.dial_size / 2)

        self.setting = 1

    def update(self):
        self.fill((0, 0, 0, 0))

        pygame.draw.circle(self, (0, 255, 0), self.center, self.dial_size / 2, 5)
        pygame.draw.circle(self, (64, 64, 64), self.center, self.dial_size / 2 * 0.95)

        angle = (1.25 - (1.5 * self.setting)) * math.pi
        x_1 = (math.cos(angle) * self.dial_size / 2 * 0.8) + (self.dial_size / 2)
        y_1 = (-1 * math.sin(angle) * self.dial_size / 2 * 0.8) + (self.dial_size / 2)
        x_2 = (math.cos(angle) * self.dial_size / 2 * 0.99) + (self.dial_size / 2)
        y_2 = (-1 * math.sin(angle) * self.dial_size / 2 * 0.99) + (self.dial_size / 2)
        pygame.draw.line(self, (0, 255, 0), (x_1, y_1), (x_2, y_2), 10)

    def set_setting(self, new_setting):
        self.setting = max(0, min(new_setting, 1))

class Surface(pygame.Surface):
    def __init__(self, window_size):
        super().__init__(window_size, pygame.SRCALPHA)
        self.running = True
        self.quit = False
        self.next_surface = ''

        dial_size = int(min(window_size[0], window_size[1]) * 0.9)
        self.dial = Dial(dial_size)
        self.dial.rect.center = (window_size[0] / 2, window_size[1] / 2)

    def update(self):
        self.fill((32, 32, 32))
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                self.running = False
                self.quit = True
            if event.type == pygame.KEYDOWN:
                if event.key == pygame.K_ESCAPE:
                    self.quit = True

        self.blit(self.dial, self.dial.rect)
        self.dial.update()
